﻿* Encoding: UTF-8.
************************************************************
*****Read data. Insert your data path before backslash between the quotation marks of /FILE="Exp1_Rawdat_included.dat".

GET DATA  /TYPE=TXT
  /FILE="\Exp1_Rawdat_included.dat"
  /ENCODING='Locale'
  /DELCASE=LINE
  /DELIMITERS="\t"
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  subject F1.0
  block F1.0
  trial F3.0
  blocktrial F2.0
  qtype F1.0
  intention F1.0
  code F2.0
  qstimseq F1.0
  default F1.0
  iresplocation F3.0
  acc F1.0
  errtype F1.0
  RT F4.0.
CACHE.
EXECUTE.
DATASET NAME Rawdat WINDOW=FRONT.

*sort data file.
SORT CASES BY subject trial.
EXECUTE.


************************************************************
*****Variables

    *qtype: 0 = mission question; 1 = routine question
    *intention: 0 = cue color indicates opposite responding; 1 = cue color indicates honest responding
    *correspondence (computed in script): 0 = non-corresponding activity and response; 1 = corresponding activity and response

    *code: questions 

           *mission questions
           Hast du eine Email verfasst? = 1
           Hast du eine Datei gesendet? = 2
           Hast du eine Tabelle geöffnet? = 3
           Hast du den USB-Stick benutzt? = 4
           Hast du den PC eingeschaltet? = 5
           Hast du ein Dreieck gezeichnet? = 6
           Hast du ein Blatt zerrissen? = 7
           Hast du eine Box geöffnet? = 8
           Hast du ein Papierstück versteckt? = 9
           Hast du einen Kreis gezeichnet? = 10

           *routine questions
           Hast du ein Kamel gestreichelt? = 11
           Hast du im Lottospiel gewonnen? = 12
           Hast du ein Fenster zerstört? = 13
           Hast du die Polizei angerufen? = 14
           Hast du einen Pilz gesammelt? = 15
           Hast du eine Straße überquert? = 16
           Hast du mit jemandem gesprochen? = 17
           Hast du eine Tür durchquert? = 18
           Hast du ein Dokument unterzeichnet? = 19
           Hast du dir Schuhe angezogen? = 20

    *qstimseq: 0 = different questions in trial n-1 and trial n; 1 = same questions in trial n-1 und trial n
    *default: 0 = not performed; 1 = performed
    *iresplocation: 0 = left response; 1 = right response delivered
    *acc: 0 = error; 1 = correct
    *errtype: 0 = no error; 1 = comission; 2 = omission; 3 = any other key pressed than d or k; 4 = early response
    *RT: reaction time.


*compute activity-response correspondence > variable: correspondence.
IF (qtype = 0 & intention = 0) correspondence = 1.
IF (qtype = 0 & intention = 1) correspondence = 0.
IF (qtype = 1) correspondence = intention.
FORMATS  correspondence(F8.0).
EXECUTE.


*********************************
*******Selecting trials.

*selecting trials where questions in trial n-1 and trial n were different.
USE ALL.
COMPUTE question_filter=(qstimseq = 0).
FORMATS question_filter (f1.0).
Filter BY question_filter.
EXECUTE. 

*eliminate practice block and first trial of each block.
FILTER OFF.
USE ALL.
SELECT IF (Block > 1 & BlockTrial > 1).
EXECUTE.


*********************************
********PE analyses: question type x correspondence.

DATASET ACTIVATE Rawdat.

*select correct and commission error trials.
USE ALL.
COMPUTE comfilter=(errtype < 2).
FORMATS comfilter (f1.0).
FILTER BY comfilter.
EXECUTE.

*use comfilter and question_filter.
USE ALL.
COMPUTE commonfilter=(question_filter = 1 & comfilter = 1).
FORMATS commonfilter (f1.0).
FILTER BY commonfilter.
EXECUTE.

*aggregate data in a new data sheet.
DATASET DECLARE PE.
AGGREGATE
  /OUTFILE='PE'
  /BREAK=Subject qtype correspondence acc
  /N_BREAK=N.
DATASET ACTIVATE PE.

*sort data for ANOVA.
SORT CASES BY subject qtype correspondence acc.
CASESTOVARS
  /ID=subject
  /INDEX= qtype correspondence acc
  /GROUPBY=VARIABLE.

*missing values (no error committed) > 0.
RECODE N_BREAK.0.0.0 N_BREAK.0.0.1 N_BREAK.0.1.0 N_BREAK.0.1.1 N_BREAK.1.0.0 N_BREAK.1.0.1 
    N_BREAK.1.1.0 N_BREAK.1.1.1 (SYSMIS=0).
EXECUTE.

*compute PE.
COMPUTE PE.0.0 = (N_BREAK.0.0.0 / (N_BREAK.0.0.0 + N_BREAK.0.0.1))*100.
COMPUTE PE.0.1 = (N_BREAK.0.1.0 / (N_BREAK.0.1.0 + N_BREAK.0.1.1))*100.
COMPUTE PE.1.0 = (N_BREAK.1.0.0 / (N_BREAK.1.0.0 + N_BREAK.1.0.1))*100.
COMPUTE PE.1.1 = (N_BREAK.1.1.0 / (N_BREAK.1.1.0 + N_BREAK.1.1.1))*100.
EXECUTE.

*check for PEs >= 50 in any cell.
USE ALL.
COMPUTE sbjct_filter=(PE.0.0 < 50 & PE.0.1 < 50 & PE.1.0 < 50 & PE.1.1 < 50).
FORMATS sbjct_filter (f1.0).
Filter BY sbjct_filter.
EXECUTE. 

*ANOVA and t-test.
GLM PE.0.0 PE.0.1 PE.1.0 PE.1.1
  /WSFACTOR=qtype 2 Polynomial correspondence 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(qtype*correspondence)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=qtype correspondence qtype*correspondence.

T-TEST PAIRS=PE.1.0 PE.0.0 WITH PE.1.1 PE.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


*********************************
********RT analyses: qtype x correspondence .

DATASET ACTIVATE Rawdat.

*select question switches and accurate trials.
USE ALL.
COMPUTE RT_filter=(code_seq = 0 & acc = 1).
FORMATS RT_filter (f1.0).
FILTER BY RT_filter.
EXECUTE.

*standardise RTs separately for each cell and eliminate outliers. 
SORT CASES  BY Subject qtype correspondence.
SPLIT FILE SEPARATE BY Subject qtype correspondence.

DELETE VARIABLES ZRT.
EXECUTE.

DESCRIPTIVES VARIABLES=RT
  /SAVE
  /STATISTICS=MEAN STDDEV SEMEAN.

COMPUTE z_filter=(ABS(ZRT) <= 2.5).
FORMATS z_filter (f1.0).
EXECUTE.

SPLIT FILE OFF.
SORT CASES BY Subject Trial.
FILTER OFF.

*use all filters (question, accuracy and outliers).
USE ALL.
COMPUTE globalRT_filter = (RT_filter = 1 & z_filter = 1).
FORMATS globalRT_filter (f1.0).
Filter BY globalRT_filter.
EXECUTE.

*aggregate data in a new data sheet.
DATASET DECLARE RTdat.
AGGREGATE
  /OUTFILE='RTdat'
  /BREAK=subject qtype correspondence
  /RT=MEAN(RT)
  /NRTs=N.

DATASET ACTIVATE RTdat.

*sort data for ANOVA.
SORT CASES BY subject qtype correspondence.
CASESTOVARS
  /ID=subject
  /INDEX= qtype correspondence
  /GROUPBY=VARIABLE.

*ANOVA and t-test.
GLM RT.0.0 RT.0.1 RT.1.0 RT.1.1
  /WSFACTOR= qtype 2 Polynomial correspondence 2 Polynomial
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(qtype*correspondence)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=qtype correspondence qtype*correspondence.

T-TEST PAIRS=RT.1.0 RT.0.0 WITH RT.1.1 RT.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


************************************************************
*Filter descriptives.

DATASET ACTIVATE Rawdat.
USE ALL.

FREQUENCIES VARIABLES= question_filter
  /STATISTICS=SUM
  /ORDER=ANALYSIS.

Filter BY question_filter.
EXECUTE. 

FREQUENCIES VARIABLES= comfilter z_filter
  /STATISTICS=SUM
  /ORDER=ANALYSIS.



