﻿* Encoding: UTF-8.
************************************************************
*****Read data. Insert your data path before backslash between the quotation marks of /FILE="\Exp3_Rawdat_included.dat".

GET DATA  /TYPE=TXT
  /FILE=
    "\Exp3_Rawdat_included.dat"
  /DELCASE=LINE
  /DELIMITERS="\t"
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  subject F1.0
  block F1.0
  trial F2.0
  blocktrial F2.0
  stimpos F1.0
  code F2.0
  default F1.0
  stimseq F1.0
  cue F1.0
  qtype F1.0
  correspondence F1.0
  distractor F1.0
  distractortype F1.0
  iresplocation F3.0
  acc F1.0
  errtype F1.0
  RT F4.0.
CACHE.
EXECUTE.
DATASET NAME Rawdat WINDOW=FRONT.
DATASET ACTIVATE Rawdat.

*sort data file.
SORT CASES BY subject trial.
EXECUTE.


************************************************************
*****Variables

    *stimpos: Position of the last part of the question and the distractors on screen
    
    *code: questions 
    
               *mission questions
               Hast du eine Email verfasst? = 1
               Hast du eine Datei gesendet? = 2
               Hast du eine Tabelle geöffnet? = 3
               Hast du den USB-Stick benutzt? = 4
               Hast du den PC eingeschaltet? = 5
               Hast du ein Dreieck gezeichnet? = 6
               Hast du ein Blatt zerrissen? = 7
               Hast du eine Box geöffnet? = 8
               Hast du ein Papierstück versteckt? = 9
               Hast du einen Kreis gezeichnet? = 10
    
               *routine questions
               Hast du ein Kamel gestreichelt? = 11
               Hast du im Lottospiel gewonnen? = 12
               Hast du ein Fenster zerstört? = 13
               Hast du die Polizei angerufen? = 14
               Hast du einen Pilz gesammelt? = 15
               Hast du eine Straße überquert? = 16
               Hast du mit jemandem gesprochen? = 17
               Hast du eine Tür durchquert? = 18
               Hast du ein Dokument unterzeichnet? = 19
               Hast du dir Schuhe angezogen? = 20

    *default: 0 = not performed; 1 = performed
    *stimseq: 0 = different questions in trial n-1 and trial n; 1 = same questions in trial n-1 und trial n
    *cue: 0 = cue color indicates opposite responding; 1 = cue color indicates honest responding
    *qtype: 0 = mission question; 1 = routine question
    *correspondence: 0 = non-corresponding activity and response; 1 = corresponding activity and response
    *distractor: NEIN (NO) = 0, JA (YES) = 1
    *distractortype: 0 = non-corresponding activity and distractor; 1 = corresponding activity and distractor
    *iresplocation: 0 = left response; 1 = right response delivered
    *acc: 0 = error; 1 = correct
    *errtype: 0 = no error; 1 = comission; 2 = omission; 3 = any other key pressed than d or k; 4 = early response
    *RT: reaction time.


*********************************
*******Selecting trials.

*eliminate practice block and first trial of each block.
FILTER OFF.
USE ALL.
SELECT IF (block > 1 & blocktrial > 1).
EXECUTE.

*selecting trials where questions in trial n-1 and trial n were different.
USE ALL.
COMPUTE question_filter=(stimseq = 0).
FORMATS question_filter (f1.0).
Filter BY question_filter.
EXECUTE. 


*********************************
********PE analyses: qtype x correspondence x distractortype.

DATASET ACTIVATE Rawdat.

*select correct and commission error trials.
USE ALL.
COMPUTE comfilter=(errtype < 2).
FORMATS comfilter (f1.0).
FILTER BY comfilter.
EXECUTE.

*use comfilter and question_filter.
USE ALL.
COMPUTE commonfilter=(question_filter = 1 & comfilter = 1).
FORMATS commonfilter (f1.0).
FILTER BY commonfilter.
EXECUTE.

*aggregate data in a new data sheet.
DATASET DECLARE Errdat.
AGGREGATE
  /OUTFILE='Errdat'
  /BREAK=Subject qtype correspondence distractortype acc
  /N_BREAK=N.
DATASET ACTIVATE Errdat.

*sort data for ANOVA.
SORT CASES BY subject qtype correspondence distractortype acc.
CASESTOVARS
  /ID=subject
  /INDEX= qtype correspondence distractortype acc
  /GROUPBY=VARIABLE.

*missing values (no error committed) > 0.
RECODE N_BREAK.0.0.0.0 N_BREAK.0.0.0.1 N_BREAK.0.0.1.0 N_BREAK.0.0.1.1 N_BREAK.0.1.0.0 
    N_BREAK.0.1.0.1 N_BREAK.0.1.1.0 N_BREAK.0.1.1.1 N_BREAK.1.0.0.0 N_BREAK.1.0.0.1 N_BREAK.1.0.1.0 
    N_BREAK.1.0.1.1 N_BREAK.1.1.0.0 N_BREAK.1.1.0.1 N_BREAK.1.1.1.0 N_BREAK.1.1.1.1 (SYSMIS=0).
EXECUTE.

*compute PE.
COMPUTE PE.0.0.0 = (N_BREAK.0.0.0.0 / (N_BREAK.0.0.0.0 + N_BREAK.0.0.0.1))*100.
COMPUTE PE.0.0.1 = (N_BREAK.0.0.1.0 / (N_BREAK.0.0.1.0 + N_BREAK.0.0.1.1))*100.
COMPUTE PE.0.1.0 = (N_BREAK.0.1.0.0 / (N_BREAK.0.1.0.0 + N_BREAK.0.1.0.1))*100.
COMPUTE PE.0.1.1 = (N_BREAK.0.1.1.0 / (N_BREAK.0.1.1.0 + N_BREAK.0.1.1.1))*100.
COMPUTE PE.1.0.0 = (N_BREAK.1.0.0.0 / (N_BREAK.1.0.0.0 + N_BREAK.1.0.0.1))*100.
COMPUTE PE.1.0.1 = (N_BREAK.1.0.1.0 / (N_BREAK.1.0.1.0 + N_BREAK.1.0.1.1))*100.
COMPUTE PE.1.1.0 = (N_BREAK.1.1.0.0 / (N_BREAK.1.1.0.0 + N_BREAK.1.1.0.1))*100.
COMPUTE PE.1.1.1 = (N_BREAK.1.1.1.0 / (N_BREAK.1.1.1.0 + N_BREAK.1.1.1.1))*100.
EXECUTE.

*check for PEs >= 50 in any cell.
USE ALL.
COMPUTE sbjct_filter=(PE.0.0.0 < 50 & PE.0.0.1 < 50 & PE.0.1.0 < 50 & PE.0.1.1 < 50 & PE.1.0.0 < 50 & PE.1.0.1 < 50 & PE.1.1.0 < 50 & PE.1.1.1 < 50).
FORMATS sbjct_filter (f1.0).
Filter BY sbjct_filter.
EXECUTE. 

************************************************************
*write PE data for between analysis: insert your data path.

SAVE TRANSLATE OUTFILE='\Exp3_PEdat.dat'
  /TYPE=TAB
  /ENCODING='UTF8'
  /MAP
  /REPLACE
  /FIELDNAMES
  /CELLS=VALUES.
************************************************************

*ANOVA.
GLM PE.0.0.0 PE.0.0.1 PE.0.1.0 PE.0.1.1 PE.1.0.0 PE.1.0.1 PE.1.1.0 PE.1.1.1
  /WSFACTOR=qtype 2 Polynomial correspondence 2 Polynomial distractor 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(correspondence*distractor*qtype)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=qtype correspondence distractor qtype*correspondence qtype*distractor 
    correspondence*distractor qtype*correspondence*distractor.

*aggregate over activity-distractor correspondence because of question type x activity-response correspondence interaction and compute t-tests.
COMPUTE PE.0.0 = (PE.0.0.0 + PE.0.0.1) / 2.
COMPUTE PE.0.1 = (PE.0.1.0 + PE.0.1.1) / 2.
COMPUTE PE.1.0 = (PE.1.0.0 + PE.1.0.1) / 2.
COMPUTE PE.1.1 = (PE.1.1.0 + PE.1.1.1) / 2.
EXECUTE.

T-TEST PAIRS=PE.1.0 PE.0.0 WITH PE.1.1 PE.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

DELETE VARIABLES PE.0.0 PE.0.1 PE.1.0 PE.1.1.

*aggregate over activity-response correspondence because of question type x activity-distractor correspondence interaction and compute t-tests.
COMPUTE PE.0.0 = (PE.0.0.0 + PE.0.1.0) / 2.
COMPUTE PE.0.1 = (PE.0.0.1 + PE.0.1.1) / 2.
COMPUTE PE.1.0 = (PE.1.0.0 + PE.1.1.0) / 2.
COMPUTE PE.1.1 = (PE.1.0.1 + PE.1.1.1) / 2.
EXECUTE.

T-TEST PAIRS=PE.0.0 PE.1.0 WITH PE.0.1 PE.1.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

DELETE VARIABLES PE.0.0 PE.0.1 PE.1.0 PE.1.1.

*compute distractor effects and t-tests for figure.
COMPUTE PE.0.0 = (PE.0.0.0 - PE.0.0.1).
COMPUTE PE.0.1 = (PE.0.1.0 - PE.0.1.1).
COMPUTE PE.1.0 = (PE.1.0.0 - PE.1.0.1).
COMPUTE PE.1.1 = (PE.1.1.0 - PE.1.1.1).
EXECUTE.

T-TEST
  /TESTVAL=0
  /MISSING=ANALYSIS
  /VARIABLES= PE.1.1 PE.1.0 PE.0.1 PE.0.0 
  /CRITERIA=CI(.95).

DELETE VARIABLES PE.0.0 PE.0.1 PE.1.0 PE.1.1.


*********************************
********RTn Analyse: qtype x correspondence x distractortype.

DATASET ACTIVATE Rawdat.

*select question switches and accurate trials.
USE ALL.
COMPUTE RT_filter=(question_filter = 1 & acc = 1).
FORMATS RT_filter (f1.0).
FILTER BY RT_filter.
EXECUTE.

*standardise RTs separately for each cell and eliminate outliers. 
SORT CASES  BY Subject qtype correspondence distractortype.
SPLIT FILE SEPARATE BY Subject qtype correspondence distractortype.

DELETE VARIABLES ZRT.
EXECUTE.

DESCRIPTIVES VARIABLES=RT
  /SAVE
  /STATISTICS=MEAN STDDEV SEMEAN.

COMPUTE z_filter=(ABS(ZRT) <= 2.5).
FORMATS z_filter (f1.0).
EXECUTE.

SPLIT FILE OFF.
SORT CASES BY Subject Trial.
FILTER OFF.

*use all filters (question, accuracy and outliers).
USE ALL.
COMPUTE globalRT_filter = (RT_filter = 1 & z_filter = 1).
FORMATS globalRT_filter (f1.0).
Filter BY globalRT_filter.
EXECUTE.

*aggregate data in a new data sheet.
DATASET DECLARE RTdat.
AGGREGATE
  /OUTFILE='RTdat'
  /BREAK=subject qtype correspondence distractortype
  /RT=MEAN(RT)
  /NRTs=N.

DATASET ACTIVATE RTdat.

*sort data for ANOVA.
SORT CASES BY subject qtype correspondence distractortype.
CASESTOVARS
  /ID=subject
  /INDEX= qtype correspondence distractortype
  /GROUPBY=VARIABLE.


************************************************************
*write RT data for between analysis: insert your data path.

DELETE VARIABLES NRTs.0.0.0 NRTs.0.0.1 NRTs.0.1.0 NRTs.0.1.1 NRTs.1.0.0 NRTs.1.0.1 NRTs.1.1.0 NRTs.1.1.1.

SAVE TRANSLATE OUTFILE='\Exp3_RTDat.dat'
  /TYPE=TAB
  /ENCODING='UTF8'
  /MAP
  /REPLACE
  /FIELDNAMES
  /CELLS=VALUES.
************************************************************

*ANOVA.
GLM RT.0.0.0 RT.0.0.1 RT.0.1.0 RT.0.1.1 RT.1.0.0 RT.1.0.1 
    RT.1.1.0 RT.1.1.1
  /WSFACTOR=qtype 2 Polynomial correspondence 2 Polynomial distractor 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=DESCRIPTIVE ETASQ 
  /PLOT=PROFILE(correspondence*distractor*qtype)
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=qtype correspondence distractor qtype*correspondence qtype*distractor 
    correspondence*distractor qtype*correspondence*distractor.

*aggregate over activity-distractor correspondence because of question type x activity-response correspondence interaction and compute t-tests.
COMPUTE RT.0.0 = (RT.0.0.0 + RT.0.0.1) / 2.
COMPUTE RT.0.1 = (RT.0.1.0 + RT.0.1.1) / 2.
COMPUTE RT.1.0 = (RT.1.0.0 + RT.1.0.1) / 2.
COMPUTE RT.1.1 = (RT.1.1.0 + RT.1.1.1) / 2.
EXECUTE.

T-TEST PAIRS= RT.1.0 RT.0.0  WITH RT.1.1 RT.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

DELETE VARIABLES RT.0.0 RT.0.1 RT.1.0 RT.1.1.

*aggregate over activity-response correspondence because of question type x activity-distractor correspondence interaction and compute t-tests.
COMPUTE RT.0.0 = (RT.0.0.0 + RT.0.1.0) / 2.
COMPUTE RT.0.1 = (RT.0.0.1 + RT.0.1.1) / 2.
COMPUTE RT.1.0 = (RT.1.0.0 + RT.1.1.0) / 2.
COMPUTE RT.1.1 = (RT.1.0.1 + RT.1.1.1) / 2.
EXECUTE.

T-TEST PAIRS=RT.0.0 RT.1.0 WITH RT.0.1 RT.1.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

DELETE VARIABLES RT.0.0 RT.0.1 RT.1.0 RT.1.1.

*compute distractor effects and t-tests for figure.
COMPUTE RT.0.0 = (RT.0.0.0 - RT.0.0.1).
COMPUTE RT.0.1 = (RT.0.1.0 - RT.0.1.1).
COMPUTE RT.1.0 = (RT.1.0.0 - RT.1.0.1).
COMPUTE RT.1.1 = (RT.1.1.0 - RT.1.1.1).
EXECUTE.

T-TEST
  /TESTVAL=0
  /MISSING=ANALYSIS
  /VARIABLES=RT.1.1 RT.1.0 RT.0.1 RT.0.0
  /CRITERIA=CI(.95).

DELETE VARIABLES  RT.1.1 RT.1.0 RT.0.1 RT.0.0.


************************************************************
*Filter descriptives.

DATASET ACTIVATE Rawdat.
USE ALL.

FREQUENCIES VARIABLES= question_filter
  /STATISTICS=SUM
  /ORDER=ANALYSIS.

Filter BY question_filter.
EXECUTE. 

FREQUENCIES VARIABLES= comfilter z_filter
  /STATISTICS=SUM
  /ORDER=ANALYSIS.
